# Man clone

> clone [old-subject-name] [new-subject-name] - In shell mode, it clones a conversation. If only one name is given it will try to clone the current conversation to the new subject name.
If two arguments are passed it will try to clone the first subject under the name of the second one.

## Usage

`clone game002`

`clone test historyOfHumanity`